@@ -8,15 +8,11 @@ import asyncio
 import copy
 import json
 import logging
-import traceback
+import os
 
 import websockets
 import httpx
 
-from websockets.exceptions import (
-    WebSocketException,
-)
-
 from speechmatics.exceptions import (
     EndOfTranscriptException,
     ForceEndSession,
@@ -429,22 +425,6 @@ class WebsocketClient:
                 extra_headers=extra_headers,
             ) as self.websocket:
                 await self._communicate(stream, audio_settings)
-        except ConnectionResetError:
-            traceback.print_exc()
-            LOGGER.error(
-                "Caught ConnectionResetError when attempting to connect to "
-                "server. The most likely reason for this is that the client "
-                "has been configured to use SSL but the server does not "
-                "support SSL. If this is the case then try using "
-                "--ssl-mode=none"
-            )
-            raise
-        except WebSocketException:
-            traceback.print_exc()
-            LOGGER.error(
-                "Caught WebSocketException when attempting to connect to server."
-            )
-            raise
         finally:
             self.session_running = False
             self._session_needs_closing = False
@@ -472,24 +452,14 @@ async def _get_temp_token(api_key):
     """
     Used to get a temporary token from management platform api for SaaS users
     """
-    mp_api_url = "https://mp.speechmatics.com"
+    mp_api_url = os.getenv("SM_MANAGEMENT_PLATFORM_URL", "https://mp.speechmatics.com")
     endpoint = mp_api_url + "/v1/api_keys"
     params = {"type": "rt"}
     body = {"ttl": 60}
     headers = {"Authorization": f"Bearer {api_key}", "Content-Type": "application/json"}
     # pylint: disable=no-member
-    try:
-        response = httpx.post(endpoint, json=body, params=params, headers=headers)
-        response.read()
-        response.raise_for_status()
-        key_object = response.json()
-        return key_object["key_value"]
-    except httpx.HTTPError as exc:
-        traceback.print_exc()
-        LOGGER.error(
-            "Error response %s while generating temporary token from %s. Details: %s",
-            exc.response.status_code,
-            exc.request.url,
-            exc.response.text,
-        )
-        raise exc
+    response = httpx.post(endpoint, json=body, params=params, headers=headers)
+    response.raise_for_status()
+    response.read()
+    key_object = response.json()
+    return key_object["key_value"]
