@@ -312,17 +312,6 @@ def test_helpful_error_message_received_on_connection_reset_error():
                 ws_client.run_synchronously(MagicMock(), MagicMock(), MagicMock())
             except ConnectionResetError as exc:
                 assert exc is not None
-            else:
-                assert False  # we should not reach else
-            mock_logger_error_method.assert_called_once()
-            # pylint: disable=unsubscriptable-object
-            assert (
-                "Caught ConnectionResetError when attempting to"
-                " connect to server"
-                # [0][0] is the first argument to the first call of the
-                # function, pylint doesn't like this.
-                in mock_logger_error_method.call_args[0][0]
-            )
 
 
 @pytest.mark.asyncio
